#
# spec file for package stardict-tools
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           stardict-tools
Version:        3.0.1
Release:        86.1
Summary:        StarDict Editor
License:        GPL-2.0-or-later
Group:          Productivity/Office/Dictionary
URL:            http://stardict.sourceforge.net
Source:         %{name}-%{version}.tar.bz2
Source1:        %{name}.README.SUSE
Source2:        stardict-editor.png
Source3:        stardict-tools-rpmlintrc
Patch1:         stardict-tools-3.0.1-includes.patch
Patch2:         stardict-tools-3.0.1-destbufferoverflow.patch
Patch3:         stardict-tools-3.0.1-gcc44.patch
Patch4:         stardict-tools-3.0.1-gcc6.patch
Patch5:         stardict-tools-3.0.1-wikipediaImage.patch
Patch6:         python3-support.patch
BuildRequires:  dos2unix
BuildRequires:  gcc-c++
BuildRequires:  gtk2-devel >= 2.6.0
BuildRequires:  pcre-devel
BuildRequires:  update-desktop-files
Recommends:     dictd
%if 0%{?suse_version} < 1010
BuildRequires:  pkgconfig
%else
BuildRequires:  libtool
BuildRequires:  pkgconfig
%endif
%if 0%{?suse_version} > 1020
BuildRequires:  libmysqlclient-devel
%else
BuildRequires:  mysql-devel
%endif

%description
This package contains the dictionary conversion tools which can convert
dictionaries of DICT, wquick, mova and pydict to stardict format.

%prep
%autosetup -p1

%build
autoreconf -fiv
%configure --with-pic --disable-static
make %{?_smp_mflags}

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
install -d -m755 %{buildroot}/%{_libdir}/%{name}
install -d -m755 %{buildroot}/%{_datadir}/{%{name},pixmaps}
install -d -m755 %{buildroot}/%{_defaultdocdir}/%{name}
pushd src 1>/dev/null
# install noinst_PROGRAMS in libdir
for file in $(grep noinst_PROGRAMS Makefile.am | sed -e 's/noinst_PROGRAMS = //'); do
	if test -x $file; then
		if [[ $file == *.exe ]]; then
			continue;
		else
			install -m755 $file %{buildroot}/%{_libdir}/%{name}/
		fi;
	fi
done
# install scripts in sharedir
for file in *.py *.pl *.perl; do
  dos2unix -q -n $file %{buildroot}/%{_datadir}/%{name}/$file
  chmod 755 %{buildroot}/%{_datadir}/%{name}/$file
done
popd 1>/dev/null
# install documentation
sed -e "s#__LIBDIR__#%{_libdir}#g" %{SOURCE1} > %buildroot/%{_defaultdocdir}/%{name}/README.SUSE
install -m644 AUTHORS ChangeLog COPYING README %{buildroot}/%{_defaultdocdir}/%{name}/
# install desktop entry
install -m644 %{SOURCE2} %{buildroot}/%{_datadir}/pixmaps/
%suse_update_desktop_file -c stardict-editor "Stardict Dictionary Editor" "Editor for stardict dictionaries" stardict-editor stardict-editor.png Office Dictionary

%files
%defattr(-, root, root)
%doc %{_defaultdocdir}/%{name}
%{_bindir}/stardict-editor
%{_libdir}/%{name}
%{_datadir}/%{name}
%{_datadir}/pixmaps/stardict-editor.png
%{_datadir}/applications/stardict-editor.desktop

%changelog
* Fri May 17 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro: allows us to eliminate usage of deprecated
  %%patchN syntax.
- Rebase stardict-tools-3.0.1-destbufferoverflow.patch and
  stardict-tools-3.0.1-gcc44.patch: make the apply witch patch -p1.
* Fri Aug 27 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add patch: python3-support.patch
  * Convert all Python 2 scripts to Python 3
- Remove shebang mangling from the specfile for python scripts.
* Sun Dec 10 2017 i@marguerite.su
- add patch: stardict-tools-3.0.1-wikipediaImage.patch
  * fix boo#1067895
  * fix MYSQL_PORT undefined
* Mon Jun 20 2016 i@marguerite.su
- add patch: stardict-tools-3.0.1-gcc6.patch
  * fix boo#985116
  * fix narrowing conversion from int to char inside {}
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun Sep 25 2011 crrodriguez@opensuse.org
- Fix build by linking with libz as well.
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Tue Jun  9 2009 coolo@novell.com
- fix build with glibc 2.10
* Fri Mar 20 2009 crrodriguez@suse.de
- fix build with gcc 44
* Wed Oct  8 2008 crrodriguez@suse.de
- fix buffer overflow
* Mon Apr 28 2008 lrupp@suse.de
- update to 3.0.1:
  + Network dictionaries support
  + Plugin system
  + Full-text translation
  + Preliminary WikiPedia dictionary support
  + More powerful dictionary management
  + Babylon dictionaries convertion
  + Many other changes
- fix some compiler issues with gcc4.3:
  stardict-tools-3.0.1-includes.patch
- fix scripts in sharedir
* Mon Jun 18 2007 lrupp@suse.de
- initial version 2.4.8: upstream splitted the tools from the
  main stardict package
